==> rest-assured-2.2.0-sources.jar: com/jayway/restassured/internal/KeystoreSpecImpl.java <==
package com.jayway.restassured.internal;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class KeystoreSpecImpl
  extends java.lang.Object  implements
    com.jayway.restassured.internal.KeystoreSpec,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getPath() { return null;}
public  void setPath(java.lang.Object value) { }
public  java.lang.Object getPassword() { return null;}
public  void setPassword(java.lang.Object value) { }
public  java.lang.String getKeyStoreType() { return (java.lang.String)null;}
public  void setKeyStoreType(java.lang.String value) { }
public  int getPort() { return (int)0;}
public  void setPort(int value) { }
public  java.security.KeyStore getTrustStore() { return (java.security.KeyStore)null;}
public  void setTrustStore(java.security.KeyStore value) { }
public  org.apache.http.conn.ssl.X509HostnameVerifier getX509HostnameVerifier() { return (org.apache.http.conn.ssl.X509HostnameVerifier)null;}
public  void setX509HostnameVerifier(org.apache.http.conn.ssl.X509HostnameVerifier value) { }
public  void apply(com.jayway.restassured.internal.http.HTTPBuilder builder, int port) { }
public  java.security.KeyStore createKeyStore() { return (java.security.KeyStore)null;}
}

==> rest-assured-2.8.0-sources.jar: com/jayway/restassured/internal/KeystoreSpecImpl.java <==
package com.jayway.restassured.internal;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class KeystoreSpecImpl
  extends java.lang.Object  implements
    com.jayway.restassured.internal.KeystoreSpec,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getPath() { return null;}
public  void setPath(java.lang.Object value) { }
public  java.lang.Object getPassword() { return null;}
public  void setPassword(java.lang.Object value) { }
public  java.lang.String getKeyStoreType() { return (java.lang.String)null;}
public  void setKeyStoreType(java.lang.String value) { }
public  int getPort() { return (int)0;}
public  void setPort(int value) { }
public  org.apache.http.conn.ssl.SSLSocketFactory getFactory() { return (org.apache.http.conn.ssl.SSLSocketFactory)null;}
public  void setFactory(org.apache.http.conn.ssl.SSLSocketFactory value) { }
public  java.security.KeyStore getTrustStore() { return (java.security.KeyStore)null;}
public  void setTrustStore(java.security.KeyStore value) { }
public  org.apache.http.conn.ssl.X509HostnameVerifier getX509HostnameVerifier() { return (org.apache.http.conn.ssl.X509HostnameVerifier)null;}
public  void setX509HostnameVerifier(org.apache.http.conn.ssl.X509HostnameVerifier value) { }
public  void apply(com.jayway.restassured.internal.http.HTTPBuilder builder, int port) { }
public  java.security.KeyStore createTrustStore() { return (java.security.KeyStore)null;}
}
